.. module:: petl

petl - Extract, Transform and Load (Tables of Data)
===================================================

:mod:`petl` is a general purpose Python package for extracting, transforming
and loading tables of data.

- Documentation: http://petl.readthedocs.org/
- Source Code: https://github.com/petl-developers/petl
- Download: http://pypi.python.org/pypi/petl
- Mailing List: http://groups.google.com/group/python-etl

Please feel free to ask questions via the mailing list
(python-etl@googlegroups.com).

To report installation problems, bugs or any other issues please email
python-etl@googlegroups.com or `raise an issue on GitHub
<https://github.com/petl-developers/petl/issues/new>`_.

For an example of :mod:`petl` in use, see the `case study on comparing tables
<http://nbviewer.ipython.org/github/petl-developers/petl/tree/master/notes/case_study_1.ipynb>`_.

For an alphabetic list of all functions in the package,
see the :ref:`genindex`.

.. note::

   Version 1.0 is a new major release of :mod:`petl`. See the :doc:`changes`
   section for more information about what has changed in version 1.0.

.. toctree::
   :maxdepth: 2

   intro
   io
   transform
   util
   config
   changes
   contributing
   acknowledgments
   related_work

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
